pub struct Rom(/* private fields */);Expand description
Processed synthesizer ROM data (control + PCM).
A ROM is either static (bundled at compile time) or owned (loaded at runtime). Both provide access to PCM samples through accessor methods.
Implementations
Sourceimpl Rom
impl Rom
Sourcepub fn default_programs(&self) -> &[usize; 8]
pub fn default_programs(&self) -> &[usize; 8]
Returns the default program index for each melodic part (8 entries).
Sourcepub fn default_panpots(&self) -> &[i32; 9]
pub fn default_panpots(&self) -> &[i32; 9]
Returns the default pan position for each part (9 entries).
Sourcepub fn reserve_settings(&self) -> &[u8; 9]
pub fn reserve_settings(&self) -> &[u8; 9]
Returns the default partial reserve setting for each part (9 entries).
Sourcepub fn fill_raw_timbres(&self, raw_timbres: &mut RawTimbreBank)
pub fn fill_raw_timbres(&self, raw_timbres: &mut RawTimbreBank)
Fills raw timbre byte arrays from the control ROM.